@@ -8,14 +8,13 @@
 #
 package Action::Retry::Strategy::Fibonacci;
 {
-  $Action::Retry::Strategy::Fibonacci::VERSION = '0.22';
+  $Action::Retry::Strategy::Fibonacci::VERSION = '0.23';
 }
 
 # ABSTRACT: Fibonacci incrementation of sleep time strategy
 
 use Math::Fibonacci qw(term);
 
-use namespace::autoclean;
 use Moo;
 
 
@@ -80,15 +79,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Action::Retry::Strategy::Fibonacci - Fibonacci incrementation of sleep time strategy
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
